@@ -14,8 +14,9 @@ import (
 	"sync"
 
 	getter "github.com/hashicorp/go-getter"
+	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/terraform-config-inspect/tfconfig"
-	"github.com/sirupsen/logrus"
+	"github.com/rs/zerolog"
 	"golang.org/x/sync/errgroup"
 
 	"github.com/infracost/infracost/internal/config"
@@ -50,11 +51,12 @@ type ModuleLoader struct {
 	cachePath string
 	cache     *Cache
 	sync      *intSync.KeyMutex
+	hclParser *SharedHCLParser
 	sourceMap config.TerraformSourceMap
 
 	packageFetcher *PackageFetcher
 	registryLoader *RegistryLoader
-	logger         *logrus.Entry
+	logger         zerolog.Logger
 }
 
 type SourceMapResult struct {
@@ -64,7 +66,7 @@ type SourceMapResult struct {
 }
 
 // NewModuleLoader constructs a new module loader
-func NewModuleLoader(cachePath string, credentialsSource *CredentialsSource, sourceMap config.TerraformSourceMap, logger *logrus.Entry, moduleSync *intSync.KeyMutex) *ModuleLoader {
+func NewModuleLoader(cachePath string, hclParser *SharedHCLParser, credentialsSource *CredentialsSource, sourceMap config.TerraformSourceMap, logger zerolog.Logger, moduleSync *intSync.KeyMutex) *ModuleLoader {
 	fetcher := NewPackageFetcher(logger)
 	// we need to have a disco for each project that has defined credentials
 	d := NewDisco(credentialsSource, logger)
@@ -72,6 +74,7 @@ func NewModuleLoader(cachePath string, credentialsSource *CredentialsSource, sou
 	m := &ModuleLoader{
 		cachePath:      cachePath,
 		cache:          NewCache(d, logger),
+		hclParser:      hclParser,
 		sourceMap:      sourceMap,
 		packageFetcher: fetcher,
 		logger:         logger,
@@ -123,7 +126,7 @@ func (m *ModuleLoader) Load(path string) (man *Manifest, err error) {
 	manifestFilePath := m.manifestFilePath(path)
 	_, err = os.Stat(manifestFilePath)
 	if errors.Is(err, os.ErrNotExist) {
-		m.logger.Debug("No existing module manifest file found")
+		m.logger.Debug().Msg("No existing module manifest file found")
 
 		tfManifestFilePath := m.tfManifestFilePath(path)
 		_, err = os.Stat(tfManifestFilePath)
@@ -145,14 +148,14 @@ func (m *ModuleLoader) Load(path string) (man *Manifest, err error) {
 				return manifest, nil
 			}
 
-			m.logger.WithError(err).Debug("error reading terraform module manifest")
+			m.logger.Debug().Err(err).Msg("error reading terraform module manifest")
 		}
 	} else if err != nil {
-		m.logger.WithError(err).Debug("error checking for existing module manifest")
+		m.logger.Debug().Err(err).Msg("error checking for existing module manifest")
 	} else {
 		manifest, err = readManifest(manifestFilePath)
 		if err != nil {
-			m.logger.WithError(err).Debug("could not read module manifest")
+			m.logger.Debug().Err(err).Msg("could not read module manifest")
 		}
 
 		if manifest.Version != supportedManifestVersion {
@@ -172,7 +175,7 @@ func (m *ModuleLoader) Load(path string) (man *Manifest, err error) {
 
 	err = writeManifest(manifest, manifestFilePath)
 	if err != nil {
-		m.logger.WithError(err).Debug("error writing module manifest")
+		m.logger.Debug().Err(err).Msg("error writing module manifest")
 	}
 
 	return manifest, nil
@@ -182,9 +185,9 @@ func (m *ModuleLoader) Load(path string) (man *Manifest, err error) {
 func (m *ModuleLoader) loadModules(path string, prefix string) ([]*ManifestModule, error) {
 	manifestModules := make([]*ManifestModule, 0)
 
-	module, diags := tfconfig.LoadModule(path)
-	if diags.HasErrors() {
-		return nil, fmt.Errorf("failed to inspect module path %s diag: %w", path, diags.Err())
+	module, err := m.loadModuleFromPath(path)
+	if err != nil {
+		return nil, err
 	}
 
 	numJobs := len(module.ModuleCalls)
@@ -206,7 +209,7 @@ func (m *ModuleLoader) loadModules(path string, prefix string) ([]*ManifestModul
 				}
 
 				// only include non-local modules in the manifest since we don't want to cache local ones.
-				if !m.isLocalModule(metadata.Source) {
+				if !isLocalModule(metadata.Source) {
 					manifestMu.Lock()
 					manifestModules = append(manifestModules, metadata)
 					manifestMu.Unlock()
@@ -227,7 +230,7 @@ func (m *ModuleLoader) loadModules(path string, prefix string) ([]*ManifestModul
 		})
 	}
 
-	err := errGroup.Wait()
+	err = errGroup.Wait()
 	if err != nil {
 		return manifestModules, fmt.Errorf("could not load modules for path %s %w", path, err)
 	}
@@ -252,38 +255,38 @@ func (m *ModuleLoader) loadModule(moduleCall *tfconfig.ModuleCall, parentPath st
 	}
 
 	if mappedResult.Source != source {
-		m.logger.Debugf("remapping module source %s to %s", source, mappedResult.Source)
+		m.logger.Debug().Msgf("remapping module source %s to %s", source, mappedResult.Source)
 		source = mappedResult.Source
 	}
 
 	if mappedResult.Version != "" {
-		m.logger.Debugf("remapping module version %s to %s", version, mappedResult.Version)
+		m.logger.Debug().Msgf("remapping module version %s to %s", version, mappedResult.Version)
 		version = mappedResult.Version
 	}
 
 	manifestModule, err := m.cache.lookupModule(key, moduleCall)
 	if err == nil {
-		m.logger.Debugf("module %s already loaded", key)
+		m.logger.Debug().Msgf("module %s already loaded", key)
 
 		// Test if we can actually load the module. If not, then we should try re-loading it.
 		// This can happen if the directory the module was downloaded to has been deleted and moved
 		// so the existing manifest.json is out-of-date.
-		_, diags := tfconfig.LoadModule(path.Join(m.cachePath, manifestModule.Dir))
-		if !diags.HasErrors() {
-			return manifestModule, err
+		_, loadModErr := m.loadModuleFromPath(path.Join(m.cachePath, manifestModule.Dir))
+		if loadModErr == nil {
+			return manifestModule, nil
 		}
 
-		m.logger.Debugf("module %s cannot be loaded, re-loading: %s", key, diags.Err())
+		m.logger.Debug().Msgf("module %s cannot be loaded, re-loading: %s", key, loadModErr)
 	} else {
-		m.logger.Debugf("module %s needs loading: %s", key, err.Error())
+		m.logger.Debug().Msgf("module %s needs loading: %s", key, err.Error())
 	}
-	if m.isLocalModule(source) {
+	if isLocalModule(source) {
 		dir, err := m.cachePathRel(filepath.Join(parentPath, source))
 		if err != nil {
 			return nil, err
 		}
 
-		m.logger.Debugf("loading local module %s from %s", key, dir)
+		m.logger.Debug().Msgf("loading local module %s from %s", key, dir)
 		return &ManifestModule{
 			Key:    key,
 			Source: source,
@@ -320,6 +323,52 @@ func (m *ModuleLoader) loadModule(moduleCall *tfconfig.ModuleCall, parentPath st
 	return manifestModule, nil
 }
 
+func (m *ModuleLoader) loadModuleFromPath(fullPath string) (*tfconfig.Module, error) {
+	mod := tfconfig.NewModule(fullPath)
+
+	fileInfos, err := os.ReadDir(fullPath)
+	if err != nil {
+		return nil, err
+	}
+
+	for _, info := range fileInfos {
+		if info.IsDir() {
+			continue
+		}
+
+		var parseFunc func(filename string) (*hcl.File, hcl.Diagnostics)
+		if strings.HasSuffix(info.Name(), ".tf") {
+			parseFunc = m.hclParser.ParseHCLFile
+		}
+
+		if strings.HasSuffix(info.Name(), ".tf.json") {
+			parseFunc = m.hclParser.ParseJSONFile
+		}
+
+		// this is not a file we can parse:
+		if parseFunc == nil {
+			continue
+		}
+
+		path := filepath.Join(fullPath, info.Name())
+		f, fileDiag := parseFunc(path)
+		if fileDiag != nil && fileDiag.HasErrors() {
+			return nil, fmt.Errorf("failed to parse file %s diag: %w", path, fileDiag)
+		}
+
+		if f == nil {
+			continue
+		}
+
+		contentDiag := tfconfig.LoadModuleFromFile(f, mod)
+		if contentDiag != nil && contentDiag.HasErrors() {
+			return nil, fmt.Errorf("failed to load module from file %s diag: %w", path, contentDiag)
+		}
+	}
+
+	return mod, nil
+}
+
 func (m *ModuleLoader) loadRegistryModule(key string, source string, version string) (*ManifestModule, error) {
 	manifestModule := &ManifestModule{
 		Key: key,
@@ -350,6 +399,7 @@ func (m *ModuleLoader) loadRegistryModule(key string, source string, version str
 		// The source might not have the registry hostname if it is using the default registry
 		// so we set the source here to the lookup result's source which always includes the registry hostname.
 		manifestModule.Source = joinModuleSubDir(lookupResult.ModuleURL.RawSource, submodulePath)
+		manifestModule.DownloadURL, _ = m.registryLoader.DownloadLocation(lookupResult.ModuleURL, lookupResult.Version)
 		manifestModule.Version = lookupResult.Version
 
 		_, err = os.Stat(dest)
@@ -413,28 +463,28 @@ func (m *ModuleLoader) cachePathRel(targetPath string) (string, error) {
 	if relerr == nil {
 		return rel, nil
 	}
-	m.logger.Infof("Failed to filepath.Rel cache=%s target=%s: %v", m.cachePath, targetPath, relerr)
+	m.logger.Info().Msgf("Failed to filepath.Rel cache=%s target=%s: %v", m.cachePath, targetPath, relerr)
 
 	// try converting to absolute paths
 	absCachePath, abserr := filepath.Abs(m.cachePath)
 	if abserr != nil {
-		m.logger.Infof("Failed to filepath.Abs cachePath: %v", abserr)
+		m.logger.Info().Msgf("Failed to filepath.Abs cachePath: %v", abserr)
 		return "", relerr
 	}
 
 	absTargetPath, abserr := filepath.Abs(targetPath)
 	if abserr != nil {
-		m.logger.Infof("Failed to filepath.Abs target: %v", abserr)
+		m.logger.Info().Msgf("Failed to filepath.Abs target: %v", abserr)
 		return "", relerr
 	}
 
-	m.logger.Infof("Attempting filepath.Rel on abs paths cache=%s, target=%s", absCachePath, absTargetPath)
+	m.logger.Info().Msgf("Attempting filepath.Rel on abs paths cache=%s, target=%s", absCachePath, absTargetPath)
 	return filepath.Rel(absCachePath, absTargetPath)
 }
 
 // isLocalModule checks if the module is a local module by checking
 // if the module source starts with any known local prefixes
-func (m *ModuleLoader) isLocalModule(source string) bool {
+func isLocalModule(source string) bool {
 	return strings.HasPrefix(source, "./") ||
 		strings.HasPrefix(source, "../") ||
 		strings.HasPrefix(source, ".\\") ||
