@@ -3,7 +3,7 @@ package google
 import (
 	"fmt"
 
-	log "github.com/sirupsen/logrus"
+	"github.com/rs/zerolog/log"
 	"github.com/tidwall/gjson"
 
 	"github.com/infracost/infracost/internal/resources/google"
@@ -58,7 +58,7 @@ func newContainerCluster(d *schema.ResourceData, u *schema.UsageData) *schema.Re
 		nameIndex := 0
 		for _, values := range d.Get("node_pool").Array() {
 			if contains(definedNodePoolNames, values.Get("name").String()) {
-				log.Debugf("Skipping node pool with name %s since it is defined in another resource", values.Get("name").String())
+				log.Debug().Msgf("Skipping node pool with name %s since it is defined in another resource", values.Get("name").String())
 				continue
 			}
 
