@@ -47,6 +47,7 @@ type HCLProvider struct {
 type HCLProviderConfig struct {
 	SuppressLogging     bool
 	CacheParsingModules bool
+	SkipAutoDetection   bool
 }
 
 type flagStringSlice []string
@@ -105,7 +106,7 @@ func NewHCLProvider(ctx *config.ProjectContext, config *HCLProviderConfig, opts
 
 	v.files = append(v.files, ctx.ProjectConfig.TerraformVarFiles...)
 	if len(v.files) > 0 {
-		withFiles := hcl.OptionWithTFVarsPaths(v.files)
+		withFiles := hcl.OptionWithTFVarsPaths(v.files, false)
 		options = append(options, withFiles)
 	}
 
@@ -135,7 +136,14 @@ func NewHCLProvider(ctx *config.ProjectContext, config *HCLProviderConfig, opts
 
 	logger := ctx.Logger().With().Str("provider", "terraform_dir").Logger()
 	runCtx := ctx.RunContext
-	locatorConfig := &hcl.ProjectLocatorConfig{ExcludedSubDirs: ctx.ProjectConfig.ExcludePaths, ChangedObjects: runCtx.VCSMetadata.Commit.ChangedObjects, UseAllPaths: ctx.ProjectConfig.IncludeAllPaths}
+	locatorConfig := &hcl.ProjectLocatorConfig{
+		SkipAutoDetection: config.SkipAutoDetection,
+		ExcludedDirs:      append(ctx.ProjectConfig.ExcludePaths, ctx.RunContext.Config.Autodetect.ExcludeDirs...),
+		IncludedDirs:      ctx.RunContext.Config.Autodetect.IncludeDirs,
+		EnvNames:          ctx.RunContext.Config.Autodetect.EnvNames,
+		ChangedObjects:    runCtx.VCSMetadata.Commit.ChangedObjects,
+		UseAllPaths:       ctx.ProjectConfig.IncludeAllPaths,
+	}
 
 	cachePath := ctx.RunContext.Config.CachePath()
 	initialPath := ctx.ProjectConfig.Path
@@ -550,42 +558,14 @@ func (p *HCLProvider) getResourceOutput(block *hcl.Block) ResourceOutput {
 	planned.Values = jsonValues
 	changes.Change.After = jsonValues
 
-	providerConfigKey := strings.Split(block.TypeLabel(), "_")[0]
-
-	providerAttr := block.GetAttribute("provider")
-	if providerAttr != nil {
-		r, err := providerAttr.Reference()
-		if err == nil {
-			providerConfigKey = r.String()
-		}
-
-		value := providerAttr.AsString()
-		if err != nil && value != "" {
-			providerConfigKey = value
-		}
-	}
-
-	var configuration ResourceData
-	if block.HasModuleBlock() {
-		configuration = ResourceData{
-			Address:           stripCountOrForEach(block.LocalName()),
-			Mode:              "managed",
-			Type:              block.TypeLabel(),
-			Name:              stripCountOrForEach(block.NameLabel()),
-			ProviderConfigKey: block.ModuleName() + ":" + block.Provider(),
-			Expressions:       blockToReferences(block),
-			CountExpression:   p.countReferences(block),
-		}
-	} else {
-		configuration = ResourceData{
-			Address:           stripCountOrForEach(block.FullName()),
-			Mode:              "managed",
-			Type:              block.TypeLabel(),
-			Name:              stripCountOrForEach(block.NameLabel()),
-			ProviderConfigKey: providerConfigKey,
-			Expressions:       blockToReferences(block),
-			CountExpression:   p.countReferences(block),
-		}
+	configuration := ResourceData{
+		Address:           stripCountOrForEach(block.LocalName()),
+		Mode:              "managed",
+		Type:              block.TypeLabel(),
+		Name:              stripCountOrForEach(block.NameLabel()),
+		ProviderConfigKey: block.ProviderConfigKey(),
+		Expressions:       blockToReferences(block),
+		CountExpression:   p.countReferences(block),
 	}
 
 	return ResourceOutput{
@@ -597,6 +577,8 @@ func (p *HCLProvider) getResourceOutput(block *hcl.Block) ResourceOutput {
 }
 
 func (p *HCLProvider) marshalProviderBlock(block *hcl.Block) string {
+	providerConfigKey := block.Values().GetAttr("config_key").AsString()
+
 	name := block.TypeLabel()
 	if a := block.GetAttribute("alias"); a != nil {
 		name = name + "." + a.AsString()
@@ -604,7 +586,7 @@ func (p *HCLProvider) marshalProviderBlock(block *hcl.Block) string {
 
 	region := block.GetAttribute("region").AsString()
 
-	p.schema.Configuration.ProviderConfig[name] = ProviderConfig{
+	p.schema.Configuration.ProviderConfig[providerConfigKey] = ProviderConfig{
 		Name: name,
 		Expressions: map[string]interface{}{
 			"region": map[string]interface{}{
@@ -620,7 +602,7 @@ func (p *HCLProvider) marshalProviderBlock(block *hcl.Block) string {
 
 	defaultTags := p.marshalDefaultTagsBlock(block)
 	if defaultTags != nil {
-		p.schema.Configuration.ProviderConfig[name].Expressions["default_tags"] = []map[string]interface{}{defaultTags}
+		p.schema.Configuration.ProviderConfig[providerConfigKey].Expressions["default_tags"] = []map[string]interface{}{defaultTags}
 	}
 
 	return name
