@@ -5,8 +5,8 @@ import (
 	"regexp"
 	"strings"
 
+	"github.com/rs/zerolog/log"
 	"github.com/shopspring/decimal"
-	log "github.com/sirupsen/logrus"
 )
 
 // nameBracketReg matches the part of a cost component name before the brackets, and the part in the brackets
@@ -64,7 +64,7 @@ func diffResourcesByKey(resourceKey string, pastResMap, currentResMap map[string
 	past, pastOk := pastResMap[resourceKey]
 	current, currentOk := currentResMap[resourceKey]
 	if current == nil && past == nil {
-		log.Debugf("diffResourcesByKey nil current and past with key %s", resourceKey)
+		log.Debug().Msgf("diffResourcesByKey nil current and past with key %s", resourceKey)
 		return false, nil
 	}
 	baseResource := current
